==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebRadioDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebComponentBoolValueChangedEventArgsDescriptionMetadata } from "./WebComponentBoolValueChangedEventArgsDescriptionMetadata";
import { VoidEventArgsDescriptionMetadata } from "./VoidEventArgsDescriptionMetadata";
import { WebRadioDescription } from "./WebRadioDescription";
/**
 * @hidden
 */
export let WebRadioDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebRadioDescriptionMetadata extends Base {
        static b(a) {
            if (WebRadioDescriptionMetadata.a == null) {
                WebRadioDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebRadioDescriptionMetadata.c(WebRadioDescriptionMetadata.a);
            }
            if (a.k(WebRadioDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebRadioDescriptionMetadata.a);
            WebComponentBoolValueChangedEventArgsDescriptionMetadata.d(a);
            VoidEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:Radio");
            a.item("__tagNameWC", "String:igc-radio");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Value", "String");
            a.item("Checked", "Boolean");
            a.item("LabelPosition", "ExportedType:string:RadioLabelPosition");
            a.item("LabelPosition@stringUnion", "WebComponents;React");
            a.item("LabelPosition@names", "Before;After");
            a.item("Disabled", "Boolean");
            a.item("Required", "Boolean");
            a.item("Name", "String");
            a.item("Invalid", "Boolean");
            a.item("ChangeRef", "EventRef::change");
            a.item("FocusRef", "EventRef::focus");
            a.item("BlurRef", "EventRef::blur");
        }
        static d(a) {
            WebRadioDescriptionMetadata.b(a);
            a.ad("WebRadio", () => new WebRadioDescription());
            a.ac("WebRadio", WebRadioDescriptionMetadata.a);
        }
    }
    WebRadioDescriptionMetadata.$t = markType(WebRadioDescriptionMetadata, 'WebRadioDescriptionMetadata');
    WebRadioDescriptionMetadata.a = null;
    return WebRadioDescriptionMetadata;
})();

==> igniteui-angular-core-19.0.1.tgz: package/esm2015/lib/WebRadioDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRadioChangeEventArgsDescriptionMetadata } from "./WebRadioChangeEventArgsDescriptionMetadata";
import { VoidEventArgsDescriptionMetadata } from "./VoidEventArgsDescriptionMetadata";
import { WebRadioDescription } from "./WebRadioDescription";
/**
 * @hidden
 */
export let WebRadioDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebRadioDescriptionMetadata extends Base {
        static b(a) {
            if (WebRadioDescriptionMetadata.a == null) {
                WebRadioDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebRadioDescriptionMetadata.c(WebRadioDescriptionMetadata.a);
            }
            if (a.k(WebRadioDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebRadioDescriptionMetadata.a);
            WebRadioChangeEventArgsDescriptionMetadata.d(a);
            VoidEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:Radio");
            a.item("__tagNameWC", "String:igc-radio");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Value", "String");
            a.item("Checked", "Boolean");
            a.item("LabelPosition", "ExportedType:string:RadioLabelPosition");
            a.item("LabelPosition@stringUnion", "WebComponents;React");
            a.item("LabelPosition@names", "After;Before");
            a.item("Disabled", "Boolean");
            a.item("Required", "Boolean");
            a.item("DefaultChecked", "Boolean");
            a.item("Name", "String");
            a.item("Invalid", "Boolean");
            a.item("ChangeRef", "EventRef::change");
            a.item("FocusRef", "EventRef::focus:skipWCPrefix");
            a.item("BlurRef", "EventRef::blur:skipWCPrefix");
        }
        static d(a) {
            WebRadioDescriptionMetadata.b(a);
            a.ae("WebRadio", () => new WebRadioDescription());
            a.ad("WebRadio", WebRadioDescriptionMetadata.a);
        }
    }
    WebRadioDescriptionMetadata.$t = markType(WebRadioDescriptionMetadata, 'WebRadioDescriptionMetadata');
    WebRadioDescriptionMetadata.a = null;
    return WebRadioDescriptionMetadata;
})();
